[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,105 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
* @brief Demonstration of graph_scope RAII usage styles
|
||||
*
|
||||
* This example shows different ways to use stackable_ctx::graph_scope_guard
|
||||
* for automatic push/pop management in nested contexts.
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main()
|
||||
{
|
||||
stackable_ctx ctx;
|
||||
|
||||
int data[10] = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10};
|
||||
auto lA = ctx.logical_data(data);
|
||||
|
||||
// Style 1: Direct constructor (like std::lock_guard)
|
||||
// This is the most idiomatic C++ style
|
||||
{
|
||||
stackable_ctx::graph_scope_guard scope{ctx}; // Direct constructor - push() called
|
||||
|
||||
auto temp = ctx.logical_data(lA.shape());
|
||||
ctx.parallel_for(temp.shape(), temp.write(), lA.read())->*[] __device__(size_t i, auto temp, auto a) {
|
||||
temp(i) = a(i) * 2;
|
||||
};
|
||||
|
||||
ctx.parallel_for(lA.shape(), lA.write(), temp.read())->*[] __device__(size_t i, auto a, auto temp) {
|
||||
a(i) = temp(i);
|
||||
};
|
||||
|
||||
// pop() called automatically when scope goes out of scope
|
||||
}
|
||||
|
||||
// Style 2: Factory method (convenience)
|
||||
// Useful when you prefer auto type deduction
|
||||
{
|
||||
auto scope = ctx.graph_scope(); // Factory method - push() called
|
||||
|
||||
ctx.parallel_for(lA.shape(), lA.rw())->*[] __device__(size_t i, auto a) {
|
||||
a(i) += 1;
|
||||
};
|
||||
|
||||
// pop() called automatically
|
||||
}
|
||||
|
||||
// Style 3: Direct constructor with explicit type alias
|
||||
// Useful for readability in complex scenarios
|
||||
{
|
||||
using scope_t = stackable_ctx::graph_scope_guard;
|
||||
scope_t scope{ctx}; // Explicit type - push() called
|
||||
|
||||
ctx.parallel_for(lA.shape(), lA.rw())->*[] __device__(size_t i, auto a) {
|
||||
a(i) *= 3;
|
||||
};
|
||||
|
||||
// pop() called automatically
|
||||
}
|
||||
|
||||
// Style 4: Iterative pattern (like in stackable2.cu)
|
||||
// Demonstrates repeated nested contexts
|
||||
for (int iter = 0; iter < 3; iter++)
|
||||
{
|
||||
stackable_ctx::graph_scope_guard iteration{ctx}; // New scope each iteration
|
||||
|
||||
auto temp = ctx.logical_data(lA.shape());
|
||||
|
||||
// tmp = a
|
||||
ctx.parallel_for(temp.shape(), temp.write(), lA.read())->*[] __device__(size_t i, auto temp, auto a) {
|
||||
temp(i) = a(i);
|
||||
};
|
||||
|
||||
// a++
|
||||
ctx.parallel_for(lA.shape(), lA.rw())->*[] __device__(size_t i, auto a) {
|
||||
a(i) += 1;
|
||||
};
|
||||
|
||||
// tmp *= 2
|
||||
ctx.parallel_for(temp.shape(), temp.rw())->*[] __device__(size_t i, auto temp) {
|
||||
temp(i) *= 2;
|
||||
};
|
||||
|
||||
// a += tmp
|
||||
ctx.parallel_for(lA.shape(), temp.read(), lA.rw())->*[] __device__(size_t i, auto temp, auto a) {
|
||||
a(i) += temp(i);
|
||||
};
|
||||
|
||||
// pop() called automatically at end of iteration
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
return 0;
|
||||
}
|
||||
Reference in New Issue
Block a user